@@ -1,2 +1,2 @@
 #from Stocks import Stocks
-import stocks.Stocks
\ No newline at end of file
+import stocks
\ No newline at end of file
